@@ -491,8 +491,13 @@ ringtoned_call_constructed (GObject *object)
         contacts = osso_abook_aggregator_find_contacts_for_im_contact (
                 aggregator, self->priv->identifier, self->priv->account);
 
+    g_free (self->priv->vcard_field);
+
     g_list_foreach (contacts, (GFunc) g_object_ref, NULL);
     self->priv->contacts = contacts;
+
+    if (G_OBJECT_CLASS (ringtoned_call_parent_class)->constructed)
+        G_OBJECT_CLASS (ringtoned_call_parent_class)->constructed (object);
 }
 
 static void
